@@ -15,12 +15,16 @@ require Exporter;
 use warnings;
 use strict;
 use Carp;
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 require XSLoader;
 XSLoader::load (__PACKAGE__, $VERSION);
 
-our $true = 1;
-our $false = 0;
+# Experimental, return a string of JSON as the error.
+
+our $json_diagnostics;
+
+our $true;
+our $false;
 our $null;
 
 sub json_to_perl
@@ -57,7 +61,7 @@ sub json_file_to_perl
 	$json .= $_;
     }
     close $in or croak $!;
-    return json_to_perl ($json);
+    return parse_json ($json);
 }
 
 1;
